.. mvdef documentation master file, created by
   sphinx-quickstart.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

mvdef: Package providing command line tools to move/copy function/classes and their associated import statements between files
==============================================================================================================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    api


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
